@@ -47,16 +47,24 @@ class Table(Media):
             "rows": len(self.data.dataframe),
         }
 
-    def to_json(self, key_name: str) -> str:
+    def to_json(self, key_name: str, only_meta:bool=False) -> str:
         assert_that(key_name).is_not_none()
 
-        return json.dumps({
-            "data": self.data.to_dict(),
-            "log_type": self.log_type,
-            "path": self.get_path(key_name),
-            "cols": len(self.data.dataframe.columns),
-            "rows": len(self.data.dataframe),
-        })
+        if only_meta:
+            return json.dumps({
+                "log_type": self.log_type,
+                "path": self.get_path(key_name),
+                "cols": len(self.data.dataframe.columns),
+                "rows": len(self.data.dataframe),
+            })
+        else:
+            return json.dumps({
+                "data": self.data.to_dict(),
+                "log_type": self.log_type,
+                "path": self.get_path(key_name),
+                "cols": len(self.data.dataframe.columns),
+                "rows": len(self.data.dataframe),
+            })
 
     # 실제 파일 서버로 전송
     # Run.log에 Image 객체가 기록된 경우 Image 의 값을 올리기 위한 함수
