@@ -17,6 +17,8 @@ URL_FINISH = "/api/client/run/finish"
 
 jwt_key: str = None
 use_http: bool =False
+cert_path: str = None
+
 def set_jwt_key(jwt_key_: str) -> None:
     global jwt_key
     jwt_key = jwt_key_
@@ -32,6 +34,15 @@ def set_use_https(use_https_: bool) -> None:
 def get_use_https() -> bool:
     global use_http
     return use_http
+
+def set_cert_path(cert_path_: bool) -> None:
+    global cert_path
+    cert_path = cert_path_
+
+def get_cert_path() -> str:
+    global cert_path
+    return cert_path
+
 # 서버의 login api 를 호출하여 API key 값을 서버로 전송하고 결과로서 jwt key 를 받는다.
 # 받은 jwt key 는 메모리에 저장해 두어서 추후 서버와 통신시 헤더에 실어서 보낼 수 있도록 한다.
 def login(http_host: str , api_key: str) -> Dict:
@@ -116,7 +127,11 @@ def finish(http_host: str ,data: Dict) -> Dict:
 
 def post(url: str, data: Dict) -> Dict:
     logger.debug(f"REST[POST] to [{url}] : data=[{json.dumps(data)}], headers=[{get_headers()}")
-    rsp = requests.post(url, headers=get_headers(), data=json.dumps(data) , verify= False)
+    cert_path = get_cert_path()
+    if cert_path is None:
+        rsp = requests.post(url, headers=get_headers(), data=json.dumps(data) , verify= False)
+    else:
+        rsp = requests.post(url, headers=get_headers(), data=json.dumps(data), verify=cert_path)
     if rsp.status_code not in [200, 201]:
         logger.debug(f"post({url}) failed({rsp.status_code})")
         try:
